@@ -272,6 +272,8 @@ def quick_train(algorithm_id: Optional[str]=None,
                 resource_polling: Union[float, int]=5,
                 hyperparams: dict={},
                 resource_request: Optional[List[Dict[str, Dict[str, int]]]]=None,
+                quota_group_name: Optional[str]=None,
+                quota_group_request: Optional[Dict[str, int]]=None,
                 task_description: Optional[str]=None):
     """
     本地算法快速训练接口。
@@ -342,7 +344,7 @@ def quick_train(algorithm_id: Optional[str]=None,
         需指定长参数名，如 :obj:`--pretrain` ，并省略 :obj:`--` 部分传入。
         预训练结果路径由Anylearn后端引擎管理。
         默认为 :obj:`pretrain` 。
-    pretrain_task_id: :obj:`List[str] | `:obj:`str`, optional
+    pretrain_task_id: :obj:`List[str]` | :obj:`str`, optional
         在Anylearn进行过的训练的ID，一般为前缀TRAI的32位字符串。
         Anylearn会对指定的训练进行结果抽取并挂载到新一次的训练中。
     project_id : :obj:`str`, optional
@@ -365,9 +367,25 @@ def quick_train(algorithm_id: Optional[str]=None,
         默认为空字典。
     resource_request : :obj:`List[Dict[str, Dict[str, int]]]`, optional
         训练所需计算资源的请求。
-        如未填，则使用Anylearn后端的:obj:`default`资源组中的默认资源套餐。
+        如未填，则使用Anylearn后端的 :obj:`default` 资源组中的默认资源套餐。
+        自0.13.1版本起，此参数被标记为废弃，将于0.14.0版本中移除。
+        请使用 :obj:`quota_group_name` 和 :obj:`quota_group_request` 作为替代。
+        
+        .. deprecated:: 0.13.1
+            
+            use :obj:`quota_group_name` and :obj:`quota_group_request` instead.
+            remove in 0.14.0.
+    quota_group_name : :obj:`str`, optional
+        训练所需计算资源组名称或ID。
+    quota_group_request : :obj:`dict`, optional
+        训练所需计算资源组中资源数量。
+        若 :obj:`quota_group_name` 和 :obj:`quota_group_request` 有其一未填，则使用Anylearn后端的 :obj:`default` 资源组中的默认资源套餐。
     task_description : :obj:`str`, optional
         训练任务详细描述。
+        若值为非空，
+        且参数 :obj:`algorithm_force_update` 为 :obj:`True` 时，
+        则Anylearn在自动提交本地算法变更时，
+        会将此值作为commit message同步至远端
 
     Returns
     -------
@@ -381,6 +399,8 @@ def quick_train(algorithm_id: Optional[str]=None,
         创建的训练项目对象
     """
     # Resource request
+    if quota_group_name and quota_group_request:
+        resource_request = [{quota_group_name: quota_group_request}]
     resource_request = _format_resource_request(resource_request)
 
     # Remote odel
@@ -408,11 +428,12 @@ def quick_train(algorithm_id: Optional[str]=None,
             uploader=resource_uploader,
             polling=resource_polling,
             force=algorithm_force_update,
+            commit_msg=task_description,
         )
     except AnylearnRequiredLocalCommitException:
         # Notify possible usage of algorithm_force_update=True
         raise AnylearnRequiredLocalCommitException(
-            f"Algorithm dir {algorithm_dir} is not clean. "
+            "Local algorithm code has uncommitted changes. "
             "Please commit your changes or "
             "specify `algorithm_force_update=True` "
             "to let Anylearn make an auto-commit."
