@@ -1,10 +1,4 @@
 from .base import BaseObject
-from .evaluate_task import (
-    EvaluateSubTask,
-    EvaluateTask,
-    EvaluateTaskState,
-    EvaluateTaskVisibility
-)
 from .mirror import Mirror
 from .project import Project, ProjectVisibility
 from .quota import QuotaGroup
