@@ -1,11 +1,42 @@
 import requests
+from requests.adapters import HTTPAdapter
 from requests.exceptions import HTTPError
+from urllib3.util.retry import Retry
 
 from anylearn.config import AnylearnConfig
 
 url_base = lambda :AnylearnConfig.cluster_address + '/api'
 
 
+class RequestRetrySession(object):
+    def __init__(
+        self,
+        retries=3,
+        backoff_factor=1,
+        status_forcelist=[429, 500, 502, 503, 504],
+        allowed_methods=["HEAD", "GET", "POST", "PUT", "PATCH", "DELETE", "OPTIONS", "TRACE"],
+        session=None,
+    ):
+        self.session = session or requests.session()
+        retry = Retry(
+            total=retries,
+            read=retries,
+            connect=retries,
+            backoff_factor=backoff_factor,
+            status_forcelist=status_forcelist,
+            allowed_methods=allowed_methods,
+        )
+        adapter = HTTPAdapter(max_retries=retry)
+        self.session.mount('http://', adapter)
+        self.session.mount('https://', adapter)
+
+    def __enter__(self):
+        return self.session
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        self.session.close()
+
+
 def __intercept(**kwargs):
     if 'headers' not in kwargs:
         kwargs['headers'] = {}
@@ -43,7 +74,7 @@ def __raise_for_status(res: requests.Response):
 
 def get_with_token(*args, **kwargs):
     kwargs = __intercept(**kwargs)
-    with requests.session() as sess:
+    with RequestRetrySession() as sess:
         res = sess.get(*args, **kwargs)
         __raise_for_status(res)
         res.encoding = "utf-8"
@@ -52,7 +83,7 @@ def get_with_token(*args, **kwargs):
 
 def post_with_token(*args, **kwargs):
     kwargs = __intercept(**kwargs)
-    with requests.session() as sess:
+    with RequestRetrySession() as sess:
         res = sess.post(*args, **kwargs)
         __raise_for_status(res)
         res.encoding = "utf-8"
@@ -62,8 +93,8 @@ def post_with_token(*args, **kwargs):
 def post_with_secret_key(*args, secret_key, **kwargs):
     if 'headers' not in kwargs:
         kwargs['headers'] = {}
-    kwargs['headers']['secret_key'] = secret_key
-    with requests.session() as sess:
+    kwargs['headers']['Secret-Key'] = secret_key
+    with RequestRetrySession() as sess:
         res = sess.post(*args, **kwargs)
         __raise_for_status(res)
         res.encoding = "utf-8"
@@ -72,7 +103,7 @@ def post_with_secret_key(*args, secret_key, **kwargs):
 
 def delete_with_token(*args, **kwargs):
     kwargs = __intercept(**kwargs)
-    with requests.session() as sess:
+    with RequestRetrySession() as sess:
         res = sess.delete(*args, **kwargs)
         __raise_for_status(res)
         res.encoding = "utf-8"
@@ -81,7 +112,7 @@ def delete_with_token(*args, **kwargs):
 
 def put_with_token(*args, **kwargs):
     kwargs = __intercept(**kwargs)
-    with requests.session() as sess:
+    with RequestRetrySession() as sess:
         res = sess.put(*args, **kwargs)
         __raise_for_status(res)
         res.encoding = "utf-8"
@@ -90,7 +121,7 @@ def put_with_token(*args, **kwargs):
 
 def patch_with_token(*args, **kwargs):
     kwargs = __intercept(**kwargs)
-    with requests.session() as sess:
+    with RequestRetrySession() as sess:
         res = sess.patch(*args, **kwargs)
         __raise_for_status(res)
         res.encoding = "utf-8"
