@@ -44,3 +44,15 @@ class AnyLearnNotSupportedException(AnyLearnException):
 
     def __init__(self, msg="暂不支持该操作"):
         super().__init__(msg)
+
+
+class AnylearnRequiredLocalCommitException(AnyLearnException):
+    """本地算法目录有未主动提交的变更"""
+
+    DEFAULT_MESSAGE = (
+        "Algorithm dir is not clean, "
+        "please commit your changes first"
+    )
+
+    def __init__(self, msg=DEFAULT_MESSAGE):
+        super().__init__(msg)
